---
title: PETsARD (/pəˈtɑrd/)
type: page
weight: 0
toc: false
---

<p style="text-align:center">
  Privacy Enhancing Technologies Analysis, Research, and Development
</p>

<p align="center"><img src="/petsard/images/PETsARD-logo.png"></p>

## Explore

{{< cards >}}
{{< card link="docs" title="Docs" icon="book-open" >}}
{{< card link="about" title="About" icon="user" >}}
{{< /cards >}}